@@ -25,8 +25,7 @@ import requests
 from hdfs import HdfsError, InsecureClient
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
-from airflow.providers.common.compat.sdk import BaseHook
+from airflow.providers.common.compat.sdk import AirflowException, BaseHook
 
 log = logging.getLogger(__name__)
 
